@@ -1,4 +1,5 @@
-__version__ = "0.2.2"
+__version__ = "0.3.0"
+
 
 from django.conf import settings
 from .replacer import replace_call
@@ -6,7 +7,7 @@ from .replacer import replace_call
 
 SQL_STACKTRACE = settings.SQL_STACKTRACE if hasattr(settings, 'SQL_STACKTRACE') else False
 if SQL_STACKTRACE:
-    from django.db.backends import BaseDatabaseWrapper
+    from django.db.backends.base.base import BaseDatabaseWrapper
     from .stacktracecursor import StacktraceCursorWrapper
 
     @replace_call(BaseDatabaseWrapper.cursor)
